/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component ("Central Component"),
                                         pHelloLabel(0),
                                         pCloseButton(0)
{
    pHelloLabel = new Label("Hello Label", tr("Привет, мир!"));
    addAndMakeVisible(pHelloLabel);
    pHelloLabel->setFont(Font(38.0000f, Font::bold));
    pHelloLabel->setJustificationType(Justification::centred);
    pHelloLabel->setEditable(false, false, false);
    pHelloLabel->setColour(Label::textColourId, Colours::blue);
    pHelloLabel->setColour(TextEditor::textColourId, Colours::black);
    pHelloLabel->setColour(TextEditor::backgroundColourId, Colours::azure);

    // Получаем рабочий каталог программы и сохраняем путь к нему
    // в виде строки
    String sPath = File::getCurrentWorkingDirectory().getFullPathName();
    // Полное имя файла изображения ненажатой кнопки
    String sUp;
    // Полное имя файла изображения нажатой кнопки
    String sDown;

    // Получаем полные имена файлов изображений для Windows и Linux
    #if JUCE_WINDOWS
        sUp = sPath + "\\gimpbutton-up.png";
        sDown = sPath + "\\gimpbutton-down.png";
    #elif JUCE_LINUX
        sUp = sPath + "/gimpbutton-up.png";
        sDown = sPath + "/gimpbutton-down.png";
    #endif

    // Изображение для ненажатой кнопки
    DrawableImage UpImage;
    // Изображение для нажатой кнопки
    DrawableImage DownImage;
    // Загружаем изображение в DrawableImage из соответствующего файла
    UpImage.setImage(ImageCache::getFromFile(File(sUp)));
    DownImage.setImage(ImageCache::getFromFile(File(sDown)));

    // Создаём пустую DrawableButton
    pCloseButton = new DrawableButton("CloseButton", DrawableButton::ImageAboveTextLabel);
    // Устанавливаем изображения для различных состояний кнопки
    pCloseButton->setImages(& UpImage, & UpImage, & DownImage);
    addAndMakeVisible(pCloseButton);
    pCloseButton->setButtonText(tr("Закрыть"));
    pCloseButton->addListener(this);

    setSize (400, 200);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pHelloLabel->setBounds(0, 0, proportionOfWidth(1.0000f), proportionOfHeight(0.9000f));
    pCloseButton->setBounds(getWidth() - 10 - 204, getHeight() - 60, 204, 53);
}
//---------------------------------------------------------------------
void TCentralComponent::buttonClicked(Button* pButton)
{
    if (pButton == pCloseButton)
    {
        JUCEApplication::quit();
    }
}
//---------------------------------------------------------------------
